@@ -461,8 +461,7 @@ void MoveClipCommand::redo()
     }
     if (m_ripple && !m_trackDelta && m_selection.size() == 1) {
         if (m_start == -1) {
-            QScopedPointer<Mlt::ClipInfo> info(m_model.findClipByUuid(MLT.uuid(m_selection.first()), trackIndex,
-                                                                      clipIndex));
+            auto info = m_model.findClipByUuid(MLT.uuid(m_selection.first()), trackIndex, clipIndex);
             if (info && info->cut) {
                 auto newStart = info->cut->get_int(kPlaylistStartProperty);
                 auto mlt_index = m_model.trackList().at(trackIndex).mlt_index;
@@ -495,7 +494,7 @@ void MoveClipCommand::redo()
     for (auto &clip : m_selection) {
         if (!m_redo) {
             // On the initial pass, remove clips while recording info about them.
-            QScopedPointer<Mlt::ClipInfo> info(m_model.findClipByUuid(MLT.uuid(clip), trackIndex, clipIndex));
+            auto info = m_model.findClipByUuid(MLT.uuid(clip), trackIndex, clipIndex);
             if (info && info->producer && info->producer->is_valid() && info->cut) {
                 info->producer->set(kNewTrackIndexProperty, qBound(0, trackIndex + m_trackDelta,
                                                                    m_model.trackList().size() - 1));
@@ -565,8 +564,9 @@ bool MoveClipCommand::mergeWith(const QUndoCommand *other)
             || that->m_rippleMarkers != m_rippleMarkers)
         return false;
     int i = 0;
+    auto thatValues = that->m_selection.values();
     for (auto &clip : m_selection) {
-        auto x = that->m_selection.values().at(i);
+        auto x = thatValues.at(i++);
         if (clip.get_producer() != x.get_producer())
             return false;
     }
@@ -1080,11 +1080,11 @@ bool TrimTransitionOutCommand::mergeWith(const QUndoCommand *other)
     return true;
 }
 
-AddTransitionByTrimInCommand::AddTransitionByTrimInCommand(MultitrackModel &model, int trackIndex,
+AddTransitionByTrimInCommand::AddTransitionByTrimInCommand(TimelineDock &timeline, int trackIndex,
                                                            int clipIndex, int duration, int trimDelta, bool redo, QUndoCommand *parent)
     : TrimCommand(parent)
-    , m_model(model)
-    , m_trackIndex(qBound(0, trackIndex, qMax(model.rowCount() - 1, 0)))
+    , m_timeline(timeline)
+    , m_trackIndex(qBound(0, trackIndex, qMax(timeline.model()->rowCount() - 1, 0)))
     , m_clipIndex(clipIndex)
     , m_duration(duration)
     , m_trimDelta(trimDelta)
@@ -1100,10 +1100,13 @@ void AddTransitionByTrimInCommand::redo()
         LOG_DEBUG() << "trackIndex" << m_trackIndex << "clipIndex" << m_clipIndex << "delta" << m_trimDelta
                     << "duration" << m_duration;
         if (m_trimDelta)
-            m_model.trimClipIn(m_trackIndex, m_clipIndex + 1, m_trimDelta, false, false);
-        m_model.addTransitionByTrimIn(m_trackIndex, m_clipIndex, m_duration);
+            m_timeline.model()->trimClipIn(m_trackIndex, m_clipIndex + 1, m_trimDelta, false, false);
+        m_timeline.model()->addTransitionByTrimIn(m_trackIndex, m_clipIndex, m_duration);
         if (m_notify && m_clipIndex > 0)
-            m_model.notifyClipOut(m_trackIndex, m_clipIndex - 1);
+            m_timeline.model()->notifyClipOut(m_trackIndex, m_clipIndex - 1);
+        m_timeline.blockSelection(false);
+        m_timeline.setSelection();
+        m_timeline.setSelection(QList<QPoint>() << QPoint(m_clipIndex + 1, m_trackIndex));
     } else {
         m_redo = true;
     }
@@ -1113,8 +1116,11 @@ void AddTransitionByTrimInCommand::undo()
 {
     if (m_clipIndex > 0) {
         LOG_DEBUG() << "trackIndex" << m_trackIndex << "clipIndex" << m_clipIndex << "delta" << m_trimDelta;
-        m_model.removeTransitionByTrimIn(m_trackIndex, m_clipIndex, -m_trimDelta);
+        m_timeline.model()->removeTransitionByTrimIn(m_trackIndex, m_clipIndex, -m_trimDelta);
         m_notify = true;
+        m_timeline.blockSelection(false);
+        m_timeline.setSelection();
+        m_timeline.setSelection(QList<QPoint>() << QPoint(m_clipIndex, m_trackIndex));
     } else LOG_WARNING() << "invalid clip index" << m_clipIndex;
 }
 
@@ -1651,7 +1657,7 @@ void AlignClipsCommand::redo()
     // Remove all the clips and remember them.
     for (auto &alignment : m_alignments) {
         int trackIndex, clipIndex;
-        QScopedPointer<Mlt::ClipInfo> info(m_model.findClipByUuid(alignment.uuid, trackIndex, clipIndex));
+        auto info = m_model.findClipByUuid(alignment.uuid, trackIndex, clipIndex);
         if (!info || !info->cut || !info->cut->is_valid()) {
             continue;
         }
